@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "LogManager.h"
 #include <Logger.h>
@@ -22,10 +9,11 @@
 
 DCORE_BEGIN_NAMESPACE
 
-/**
- * \class DLogManager
- *
- * \brief DLogManager is the deepin user application log manager
+/*!
+  \class Dtk::Core::DLogManager
+  \inmodule dtkcore
+  
+  \brief DLogManager is the deepin user application log manager.
  */
 
 DLogManager::DLogManager()
@@ -51,29 +39,32 @@ void DLogManager::initRollingFileAppender(){
     logger->registerAppender(m_rollingFileAppender);
 }
 
-//! Registers the appender to write the log records to the Console
-/**
- * \sa registerFileAppender
+/*!
+  \brief Registers the appender to write the log records to the Console.
+
+  \sa registerFileAppender
  */
 void DLogManager::registerConsoleAppender(){
     DLogManager::instance()->initConsoleAppender();
 }
 
-//! Registers the appender to write the log records to the file
-/**
- * \sa getlogFilePath
- * \sa registerConsoleAppender
+/*!
+  \brief Registers the appender to write the log records to the file.
+
+  \sa getlogFilePath
+  \sa registerConsoleAppender
  */
 void DLogManager::registerFileAppender() {
     DLogManager::instance()->initRollingFileAppender();
 }
 
-//! Return the path file log storage
-/**
- * \~chinese \brief DLogManager::getlogFilePath 获取日志文件路径
- * \~chinese \brief 默认日志路径是 ~/.cache/organizationName/applicationName.log
- * \~chinese \brief 如果获取 HOME 环境变量失败将不写日志
- * \sa registerFileAppender
+/*!
+  \brief Return the path file log storage.
+
+  \brief DLogManager::getlogFilePath 获取日志文件路径
+  \brief 默认日志路径是 ~/.cache/organizationName/applicationName.log
+  \brief 如果获取 HOME 环境变量失败将不写日志
+  \sa registerFileAppender
  */
 QString DLogManager::getlogFilePath()
 {
@@ -98,9 +89,9 @@ QString DLogManager::getlogFilePath()
 }
 
 /*!
- * \~chinese \brief DLogManager::setlogFilePath 设置日志文件路径
- * \~chinese \param logFilePath 日志文件路径
- * \~chinese \brief 如果设置的文件路进不是文件路径将什么都不做，输出一条警告
+  \brief DLogManager::setlogFilePath 设置日志文件路径
+  \a logFilePath 日志文件路径
+  \brief 如果设置的文件路进不是文件路径将什么都不做，输出一条警告
  */
 void DLogManager::setlogFilePath(const QString &logFilePath)
 {
